@@ -48,7 +48,7 @@
 CantorShell::CantorShell()
     : KParts::MainWindow( )
 {
-    m_part=0;
+    m_part=nullptr;
 
     // set the shell's ui resource file
     setXMLFile(QLatin1String("cantor_shell.rc"));
@@ -56,7 +56,7 @@ CantorShell::CantorShell()
     // then, setup our actions
     setupActions();
 
-    createGUI(0);
+    createGUI(nullptr);
 
     m_tabWidget=new QTabWidget(this);
     m_tabWidget->setTabsClosable(true);
@@ -274,9 +274,25 @@ void CantorShell::addWorksheet(const QString& backendName)
         if (part)
         {
             connect(part, SIGNAL(setWindowCaption(const QString&)), this, SLOT(setTabCaption(const QString&)));
-
             m_parts.append(part);
-            int tab = m_tabWidget->addTab(part->widget(), i18n("Session %1", sessionCount++));
+
+            //determine the icon of the backend to be added
+            Cantor::Backend* backend = nullptr;
+            for (Cantor::Backend* b : Cantor::Backend::availableBackends())
+            {
+                if (b->name() == backendName)
+                {
+                    backend = b;
+                    break;
+                }
+            }
+
+            int tab = -1;
+            if (backend)
+                tab = m_tabWidget->addTab(part->widget(), QIcon::fromTheme(backend->icon()), i18n("Session %1", sessionCount++));
+            else //should never happend but just in case we still have some bugs somewhere...
+                tab = m_tabWidget->addTab(part->widget(), i18n("Session %1", sessionCount++));
+
             m_tabWidget->setCurrentIndex(tab);
         }
         else
@@ -494,20 +510,18 @@ KParts::ReadWritePart* CantorShell::findPart(QWidget* widget)
         if(part->widget()==widget)
             return part;
     }
-    return 0;
+    return nullptr;
 }
 
 void CantorShell::updatePanel()
 {
-    qDebug()<<"updating panels";
-
     unplugActionList(QLatin1String("view_show_panel_list"));
 
     //remove all of the previous panels (but do not delete the widgets)
     foreach(QDockWidget* dock, m_panels)
     {
         QWidget* widget=dock->widget();
-        if(widget!=0)
+        if(widget!=nullptr)
         {
             widget->setParent(this);
             widget->hide();
@@ -525,12 +539,12 @@ void CantorShell::updatePanel()
         return;
     }
 
-    QDockWidget* last=0;
+    QDockWidget* last=nullptr;
 
     QList<Cantor::PanelPlugin*> plugins=handler->plugins();
     foreach(Cantor::PanelPlugin* plugin, plugins)
     {
-        if(plugin==0)
+        if(plugin==nullptr)
         {
             qDebug()<<"somethings wrong";
             continue;
@@ -544,7 +558,7 @@ void CantorShell::updatePanel()
         docker->setWidget(plugin->widget());
         addDockWidget ( Qt::RightDockWidgetArea,  docker );
 
-        if(last!=0)
+        if(last!=nullptr)
             tabifyDockWidget(last, docker);
         last=docker;
 
@@ -565,7 +579,7 @@ void CantorShell::updatePanel()
     {
         if (!backend->isEnabled())
             continue;
-        QAction * action = new QAction(QIcon::fromTheme(backend->icon()), backend->name(), 0);
+        QAction * action = new QAction(QIcon::fromTheme(backend->icon()), backend->name(), nullptr);
         action->setData(backend->name());
         connect(action, SIGNAL(triggered()), this, SLOT(fileNew()));
         newBackendActions << action;
