@@ -77,7 +77,7 @@ class WorksheetAccessInterfaceImpl : public Cantor::WorksheetAccessInterface
 
     }
 
-    ~WorksheetAccessInterfaceImpl()
+    ~WorksheetAccessInterfaceImpl() override
     {
 
     }
@@ -111,13 +111,13 @@ class WorksheetAccessInterfaceImpl : public Cantor::WorksheetAccessInterface
     Worksheet* m_worksheet;
 };
 
-CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantList & args ): KParts::ReadWritePart(parent)
+CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantList & args ): KParts::ReadWritePart(parent),
+    m_searchBar(nullptr),
+    m_initProgressDlg(nullptr),
+    m_showProgressDlg(true),
+    m_showBackendHelp(nullptr),
+    m_statusBarBlocked(false)
 {
-    m_showBackendHelp=0;
-    m_initProgressDlg=0;
-    m_statusBarBlocked=false;
-    m_showProgressDlg=true;
-
     qDebug()<<"Created a CantorPart";
 
     m_panelHandler=new Cantor::PanelPluginHandler(this);
@@ -161,12 +161,12 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     connect(actionCollection(), SIGNAL(inserted(QAction*)), m_worksheet,
             SLOT(registerShortcut(QAction*)));
 
-    m_searchBar = 0;
     layout->addWidget(m_worksheetview);
     // notify the part that this is our internal widget
     setWidget(widget);
 
     Cantor::WorksheetAccessInterface* iface=new WorksheetAccessInterfaceImpl(this, m_worksheet);
+    Q_UNUSED(iface);
 
     // create our actions
     m_worksheet->createActions(actionCollection());
@@ -239,6 +239,7 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     m_evaluate=new QAction(i18n("Evaluate Worksheet"), actionCollection());
     actionCollection()->addAction(QLatin1String("evaluate_worksheet"), m_evaluate);
     m_evaluate->setIcon(QIcon::fromTheme(QLatin1String("system-run")));
+    m_evaluate->setShortcut(Qt::CTRL+Qt::Key_E);
     connect(m_evaluate, SIGNAL(triggered()), this, SLOT(evaluateOrInterrupt()));
 
     m_typeset=new KToggleAction(i18n("Typeset using LaTeX"), actionCollection());
@@ -417,7 +418,7 @@ KAboutData& CantorPart::createAboutData()
 bool CantorPart::openFile()
 {
     //don't crash if for some reason the worksheet is invalid
-    if(m_worksheet==0)
+    if(m_worksheet==nullptr)
     {
         qWarning()<<"trying to open in an invalid cantor part";
         return false;
@@ -529,12 +530,14 @@ void CantorPart::worksheetStatusChanged(Cantor::Session::Status status)
     if(status==Cantor::Session::Running)
     {
         m_evaluate->setText(i18n("Interrupt"));
+        m_evaluate->setShortcut(Qt::CTRL+Qt::Key_I);
         m_evaluate->setIcon(QIcon::fromTheme(QLatin1String("dialog-close")));
 
         setStatusMessage(i18n("Calculating..."));
     }else
     {
         m_evaluate->setText(i18n("Evaluate Worksheet"));
+        m_evaluate->setShortcut(Qt::CTRL+Qt::Key_E);
         m_evaluate->setIcon(QIcon::fromTheme(QLatin1String("system-run")));
 
         setStatusMessage(i18n("Ready"));
@@ -578,6 +581,7 @@ void CantorPart::worksheetSessionLoginStarted() {
 }
 
 void CantorPart::worksheetSessionLoginDone() {
+    setStatusMessage(i18n("Ready"));
     QApplication::restoreOverrideCursor();
 }
 
@@ -738,7 +742,7 @@ void CantorPart::findPrev()
 
 void CantorPart::searchBarDeleted()
 {
-    m_searchBar = 0;
+    m_searchBar = nullptr;
     m_findNext->setEnabled(false);
     m_findPrev->setEnabled(false);
 }
