@@ -29,7 +29,7 @@
 
 ImageEntry::ImageEntry(Worksheet* worksheet) : WorksheetEntry(worksheet)
 {
-    m_imageItem = 0;
+    m_imageItem = nullptr;
     m_textItem = new WorksheetTextItem(this);
     m_imageWatcher = new QFileSystemWatcher(this);
     m_displaySize.width = -1;
@@ -223,7 +223,7 @@ void ImageEntry::updateEntry()
         }
 
         if (!m_imageItem->imageIsValid()) {
-            const QString msg = i18n("Cannot load image %1").arg(m_imagePath);
+            const QString msg = i18n("Cannot load image %1", m_imagePath);
             m_textItem->setPlainText(msg);
             m_textItem->setVisible(true);
             m_imageItem->setVisible(false);
