@@ -49,7 +49,7 @@ class CANTOR_EXPORT DefaultHighlighter : public QSyntaxHighlighter
   Q_OBJECT
   public:
     DefaultHighlighter(QObject* parent);
-    ~DefaultHighlighter();
+    ~DefaultHighlighter() override;
 
     /**
      * Change the item being highlighted.
@@ -68,7 +68,7 @@ class CANTOR_EXPORT DefaultHighlighter : public QSyntaxHighlighter
      * The default implementation calls highlightPairs(), highlightWords() and highlightRegExps().
      *
      */
-    virtual void highlightBlock(const QString& text);
+    void highlightBlock(const QString& text) Q_DECL_OVERRIDE;
 
     bool skipHighlighting(const QString& text);
 
