@@ -24,16 +24,14 @@
 #include <QParallelAnimationGroup>
 #include <QPropertyAnimation>
 #include <QScrollBar>
-#include <QDebug>
 
-WorksheetView::WorksheetView(Worksheet* scene, QWidget* parent)
-    : QGraphicsView(scene, parent)
+WorksheetView::WorksheetView(Worksheet* scene, QWidget* parent) : QGraphicsView(scene, parent),
+    m_scale(1),
+    m_animation(nullptr),
+    m_hAnimation(nullptr),
+    m_vAnimation(nullptr),
+    m_worksheet(scene)
 {
-    m_scale = 1;
-    m_animation = 0;
-    m_hAnimation = 0;
-    m_vAnimation = 0;
-    m_worksheet = scene;
     connect(scene, SIGNAL(sceneRectChanged(const QRectF&)),
             this, SLOT(sceneRectChanged(const QRectF&)));
     setAlignment(Qt::AlignLeft | Qt::AlignTop);
@@ -41,10 +39,6 @@ WorksheetView::WorksheetView(Worksheet* scene, QWidget* parent)
     setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 }
 
-WorksheetView::~WorksheetView()
-{
-}
-
 void WorksheetView::makeVisible(const QRectF& sceneRect)
 {
     const qreal w = viewport()->width();
@@ -70,8 +64,6 @@ void WorksheetView::makeVisible(const QRectF& sceneRect)
     else
         y = 0;
 
-    qDebug() << rect << QRectF(x,y,w,h);
-
     if (!m_animation && QRectF(x,y,w,h).contains(rect))
         return;
 
@@ -85,8 +77,6 @@ void WorksheetView::makeVisible(const QRectF& sceneRect)
     else
         nx = rect.x() + rect.width() - w;
 
-    qDebug() << nx << ny;
-
     if (!m_worksheet->animationsEnabled()) {
         if (horizontalScrollBar())
             horizontalScrollBar()->setValue(nx);
@@ -118,7 +108,7 @@ void WorksheetView::makeVisible(const QRectF& sceneRect)
             m_hAnimation->setEndValue(nx);
         }
     } else {
-        m_hAnimation = 0;
+        m_hAnimation = nullptr;
     }
 
     if (verticalScrollBar()) {
@@ -139,17 +129,16 @@ void WorksheetView::makeVisible(const QRectF& sceneRect)
                                     value * ny);
             m_vAnimation->setStartValue(sy);
             m_vAnimation->setEndValue(ny);
-            //qDebug() << sy << value << ny;
         }
     } else {
-        m_vAnimation = 0;
+        m_vAnimation = nullptr;
     }
 
     connect(m_animation, &QParallelAnimationGroup::finished, this, &WorksheetView::endAnimation);
     m_animation->start();
 }
 
-bool WorksheetView::isVisible(const QRectF& sceneRect)
+bool WorksheetView::isVisible(const QRectF& sceneRect) const
 {
     const qreal w = viewport()->width();
     const qreal h = viewport()->height();
@@ -174,7 +163,7 @@ bool WorksheetView::isVisible(const QRectF& sceneRect)
     return QRectF(x,y,w,h).contains(rect);
 }
 
-bool WorksheetView::isAtEnd()
+bool WorksheetView::isAtEnd() const
 {
     bool atEnd = true;
     if (verticalScrollBar())
@@ -182,7 +171,7 @@ bool WorksheetView::isAtEnd()
     return atEnd;
 }
 
-void WorksheetView::scrollToEnd()
+void WorksheetView::scrollToEnd() const
 {
     if (verticalScrollBar())
         verticalScrollBar()->setValue(verticalScrollBar()->maximum());
@@ -216,22 +205,22 @@ void WorksheetView::endAnimation()
         return;
 
     m_animation->deleteLater();
-    m_hAnimation = 0;
-    m_vAnimation = 0;
-    m_animation = 0;
+    m_hAnimation = nullptr;
+    m_vAnimation = nullptr;
+    m_animation = nullptr;
 }
 
-QPoint WorksheetView::viewCursorPos()
+QPoint WorksheetView::viewCursorPos() const
 {
     return viewport()->mapFromGlobal(QCursor::pos());
 }
 
-QPointF WorksheetView::sceneCursorPos()
+QPointF WorksheetView::sceneCursorPos() const
 {
     return mapToScene(viewCursorPos());
 }
 
-QRectF WorksheetView::viewRect()
+QRectF WorksheetView::viewRect() const
 {
     const qreal w = viewport()->width() / m_scale;
     const qreal h = viewport()->height() / m_scale;
@@ -240,13 +229,13 @@ QRectF WorksheetView::viewRect()
     return QRectF(x, y, w, h);
 }
 
-void WorksheetView::resizeEvent(QResizeEvent * event)
+void WorksheetView::resizeEvent(QResizeEvent* event)
 {
     QGraphicsView::resizeEvent(event);
     updateSceneSize();
 }
 
-qreal WorksheetView::scaleFactor()
+qreal WorksheetView::scaleFactor() const
 {
     return m_scale;
 }
@@ -258,7 +247,7 @@ void WorksheetView::updateSceneSize()
     sendViewRectChange();
 }
 
-void WorksheetView::sceneRectChanged(const QRectF& sceneRect)
+void WorksheetView::sceneRectChanged(const QRectF& sceneRect) const
 {
     Q_UNUSED(sceneRect);
     if (verticalScrollBar())
@@ -269,7 +258,7 @@ void WorksheetView::sceneRectChanged(const QRectF& sceneRect)
                 this, SLOT(sendViewRectChange()), Qt::UniqueConnection);
 }
 
-void WorksheetView::sendViewRectChange()
+void WorksheetView::sendViewRectChange() const
 {
     emit viewRectChanged(viewRect());
 }
@@ -287,5 +276,3 @@ void WorksheetView::zoomOut()
     scale(1/1.1, 1/1.1);
     updateSceneSize();
 }
-
-
